@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -35,7 +35,7 @@ public Q_SLOTS:
     void slotFind();
 
 private:
-    void initialize(KSieveUi::SieveTextEdit *custom = nullptr);
+    KSIEVEUI_NO_EXPORT void initialize(KSieveUi::SieveTextEdit *custom = nullptr);
     std::unique_ptr<SieveTextEditWidgetPrivate> const d;
     KSieveUi::SieveTextEdit *mTextEdit = nullptr;
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
